@@ -1,4 +1,5 @@
 #include <libavcodec/avcodec.h>
+#include <libavutil/channel_layout.h>
 
 static const AVCodec* ffw_find_codec(const char* name, int type) {
     const AVCodec* codec;
@@ -82,7 +83,7 @@ int ffw_codec_parameters_is_subtitle_codec(const AVCodecParameters* params) {
 }
 
 const char* ffw_codec_parameters_get_decoder_name(const AVCodecParameters* params) {
-    AVCodec* codec = avcodec_find_decoder(params->codec_id);
+    const AVCodec* codec = avcodec_find_decoder(params->codec_id);
     if (!codec) {
         return NULL;
     }
@@ -91,7 +92,7 @@ const char* ffw_codec_parameters_get_decoder_name(const AVCodecParameters* param
 }
 
 const char* ffw_codec_parameters_get_encoder_name(const AVCodecParameters* params) {
-    AVCodec* codec = avcodec_find_encoder(params->codec_id);
+    const AVCodec* codec = avcodec_find_encoder(params->codec_id);
     if (!codec) {
         return NULL;
     }
@@ -184,7 +185,7 @@ void ffw_codec_parameters_free(AVCodecParameters* params) {
 }
 
 typedef struct Decoder {
-    struct AVCodec* decoder;
+    const struct AVCodec* decoder;
     struct AVDictionary* options;
     struct AVCodecContext* cc;
     struct AVFrame* frame;
@@ -201,7 +202,7 @@ AVCodecParameters* ffw_decoder_get_codec_parameters(const Decoder* decoder);
 void ffw_decoder_free(Decoder* decoder);
 
 Decoder* ffw_decoder_new(const char* codec) {
-    AVCodec* decoder = avcodec_find_decoder_by_name(codec);
+    const AVCodec* decoder = avcodec_find_decoder_by_name(codec);
     if (decoder == NULL) {
         return NULL;
     }
@@ -235,7 +236,7 @@ err:
 }
 
 Decoder* ffw_decoder_from_codec_parameters(const AVCodecParameters* params) {
-    AVCodec* decoder = avcodec_find_decoder(params->codec_id);
+    const AVCodec* decoder = avcodec_find_decoder(params->codec_id);
     if (decoder == NULL) {
         return NULL;
     }
@@ -382,7 +383,7 @@ void ffw_decoder_free(Decoder* decoder) {
 typedef struct Encoder {
     struct AVDictionary* options;
     struct AVCodecContext* cc;
-    struct AVCodec* codec;
+    const struct AVCodec* codec;
     struct AVPacket* packet;
 } Encoder;
 
@@ -409,7 +410,7 @@ int ffw_encoder_take_packet(Encoder* encoder, AVPacket** packet);
 void ffw_encoder_free(Encoder* encoder);
 
 Encoder* ffw_encoder_new(const char* codec) {
-    AVCodec* encoder = avcodec_find_encoder_by_name(codec);
+    const AVCodec* encoder = avcodec_find_encoder_by_name(codec);
     if (encoder == NULL) {
         return NULL;
     }
@@ -443,7 +444,7 @@ err:
 }
 
 Encoder* ffw_encoder_from_codec_parameters(const AVCodecParameters* params) {
-    AVCodec* encoder = avcodec_find_encoder(params->codec_id);
+    const AVCodec* encoder = avcodec_find_encoder(params->codec_id);
     if (encoder == NULL) {
         return NULL;
     }
